AppInfo class

Constructors

AppInfo()

Properties

appName ↔ String
getter/setter pair
buildNumber ↔ String
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
packageName ↔ String
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
version ↔ String
getter/setter pair

Methods

getAppInfo() → Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited